==> node_plsql-0.6.0.tgz: package/HISTORY.md <==
v0.0.1 - May 24, 2014
* 0.0.1 (Dieter Oberkofler)
* initial check-in as a proof of concept. (Dieter Oberkofler)
* support for flexible parameter passing. (Dieter Oberkofler)
* support for all required cgi parameters including cookies. (Dieter Oberkofler)
* support for static files. (Dieter Oberkofler)
* support for non-blocking Oracle requests. (Dieter Oberkofler)
* support for Oracle connection pooling. (Dieter Oberkofler)

v0.0.2 - May 29, 2014
* 0.0.2 (Dieter Oberkofler)
* Added support for file uploads. (Dieter Oberkofler)
* Added support for parsing multipart-form data requests. (Dieter Oberkofler)
* Added support for form data requests. (Dieter Oberkofler)
* Added configuration option "requestLogging" allowing enable/disable the http request logging middleware. (Dieter Oberkofler)
* Switched from Makefile to Gruntfile. (Dieter Oberkofler)
* update "express" to 4.3.2 (Dieter Oberkofler)
* update "mocha" to 1.20.0 (Dieter Oberkofler)
* update "morgan" to 1.1.1 (Dieter Oberkofler)
* update "strip-json-comments" to 0.1.3 (Dieter Oberkofler)

v0.0.3 - May 30, 2014
* 0.0.3 (Dieter Oberkofler)
* Add support for darwin. (Dieter Oberkofler)

v0.0.4 - May 31, 2014
* 0.0.4 (Dieter Oberkofler)
* Add support for default pages. (Dieter Oberkofler)
* Added jscs linting. (Dieter Oberkofler)
* update "express" to 4.4.0 (Dieter Oberkofler)
* update "compression" to 1.0.3 (Dieter Oberkofler)
* update "serve-static" to 1.1.0 (Dieter Oberkofler)

v0.0.5 - May 31, 2014
* 0.0.5 (Dieter Oberkofler)
* Extracted the database interface and created a shim for testing purposes. (Dieter Oberkofler)
* Added integration test framework. (Dieter Oberkofler)
* Added proper error handling for 404 and 500 error messages. (Dieter Oberkofler)
* Added proper error handling for Oracle error messages. (Dieter Oberkofler)

v0.0.6 - skipped

v0.0.7 - June 12, 2014
* 0.0.7 (Dieter Oberkofler)
* Switched from blanket to istanbul for code coverage. (Dieter Oberkofler)
* Improved code coverage to 100%. (Dieter Oberkofler)
* update "body-parser" to 1.3.1 (Dieter Oberkofler)
* update "compression" to 1.0.7 (Dieter Oberkofler)
* update "connect-multiparty" to 1.0.5 (Dieter Oberkofler)
* update "debug" to 1.0.2 (Dieter Oberkofler)
* update "express" to 4.4.3 (Dieter Oberkofler)
* update "serve-static" to 1.2.3 (Dieter Oberkofler)

v0.0.8 - June 13, 2014
* 0.0.8 (Dieter Oberkofler)
* Just fixed a formatting error in README. (Dieter Oberkofler)

v0.0.9 - June 16, 2014
* 0.0.9 (Dieter Oberkofler)
* Added a basic status page. (Dieter Oberkofler)
* Fixed a logging error. (Dieter Oberkofler)

v0.0.10 - June 20, 2014
* 0.0.10 (Dieter Oberkofler)
* Added support for Node 0.11. (Dieter Oberkofler)
* Migrated v8 interface to nan. (Dieter Oberkofler)
* Fixed a small intermittent problem caused by using mkdirp in async mode. (Dieter Oberkofler)
* update "cookie-parser" to 1.3.1 (Dieter Oberkofler)
* update "body-parser" to 1.4.3 (Dieter Oberkofler)

v0.0.11 - June 21, 2014
* 0.0.11 (Dieter Oberkofler)
* Fixed usage mkdirp in async mode in test. (Dieter Oberkofler)
* Added unit tests for static files. (Dieter Oberkofler)
* update "compression" to 1.0.8 (Dieter Oberkofler)
* update "express" to 4.4.4 (Dieter Oberkofler)

v0.0.12 - August 16, 2014
* 0.0.12 (Dieter Oberkofler)
* Renamed the server module from lib/node_plsql.js to lib/server.js to make sure that only the client in bin is used locally. (Dieter Oberkofler)
* Adapted server to the latest express version. (Dieter Oberkofler)
* Added a better installation example in the README. (Dieter Oberkofler)
* Added separate documentation for local and global installation. (Dieter Oberkofler)
* Added missing configuration samples to the npm tarball. (Dieter Oberkofler)
* Separated the development information into a separate DEVELOPMENT.md file. (Dieter Oberkofler)
* update "body-parser" to 1.6.4 (Dieter Oberkofler)
* update "compression" to 1.0.11 (Dieter Oberkofler)
* update "connect-multiparty" to 1.2.1 (Dieter Oberkofler)
* update "cookie-parser" to 1.3.2 (Dieter Oberkofler)
* update "debug" to 1.0.4 (Dieter Oberkofler)
* update "express" to 4.8.4 (Dieter Oberkofler)
* update "js-yaml" to 3.1.0 (Dieter Oberkofler)
* update "morgan" to 1.2.2 (Dieter Oberkofler)
* update "nopt" to 3.0.1 (Dieter Oberkofler)
* update "serve-static" to 1.5.2 (Dieter Oberkofler)
* update "strip-json-comments" to 1.0.1 (Dieter Oberkofler)

v0.0.13 - October 27, 2014
* 0.0.13 (Dieter Oberkofler)
* update "body-parser" to 1.9.1 (Dieter Oberkofler)
* update "compression" to 1.2.0 (Dieter Oberkofler)
* update "connect-multiparty" to 1.2.5 (Dieter Oberkofler)
* update "cookie-parser" to 1.3.3 (Dieter Oberkofler)
* update "debug" to 2.1.0 (Dieter Oberkofler)
* update "express" to 4.10.0 (Dieter Oberkofler)
* update "js-yaml" to 3.2.3 (Dieter Oberkofler)
* update "morgan" to 1.4.1 (Dieter Oberkofler)
* update "serve-static" to 1.7.1 (Dieter Oberkofler)
* update "strip-json-comments" to 1.0.2 (Dieter Oberkofler)
* update "underscore" to 1.7.0 (Dieter Oberkofler)

v0.1.0 - November 11, 2014
* 0.1.0 (Dieter Oberkofler)
* Binaries (only node-v11-win32-x64) now hosted in S3 using node-pre-gyp (Dieter Oberkofler)
* Minor improvements in the usage of the cli. (Dieter Oberkofler)
* update "body-parser" to 1.9.2 (Dieter Oberkofler)
* update "js-yaml" to 3.2.3 (Dieter Oberkofler)
* update "nan" to 1.4.1 (Dieter Oberkofler)
* update "chai" to 1.10.0 (Dieter Oberkofler)
* update "morgan" to 1.5.0 (Dieter Oberkofler)
* update "express" to 4.10.2 (Dieter Oberkofler)

v0.1.1 - December 20, 2014
* 0.1.1 (Dieter Oberkofler)
* Binaries (only node-v11-win32-x64) now hosted in S3 using node-pre-gyp (Dieter Oberkofler)
* Migrated from grunt to gulp. (Dieter Oberkofler)
* update "body-parser" to 1.10.0 (Dieter Oberkofler)
* update "compression" to 1.2.2 (Dieter Oberkofler)
* update "express" to 4.10.6 (Dieter Oberkofler)
* update "js-yaml" to 3.2.4 (Dieter Oberkofler)
* update "ms" to 0.7.0 (Dieter Oberkofler)

v0.2.0 - March 4, 2015
* 0.2.0 (Dieter Oberkofler)
* Support for Node.js 0.2.0. (Dieter Oberkofler)
* Migrated from jshint and esjs to eslint. (Dieter Oberkofler)
* Updated all dependencies to latest release. (Dieter Oberkofler)
* Internal errors (500) now whow the internal error stack. (Dieter Oberkofler)

v0.3.0 - March 14, 2015
* 0.3.0 (Dieter Oberkofler)
* Impoved the CGI parameter available to the Oracle backend. (Dieter Oberkofler)
* Support for io.js. (Dieter Oberkofler)
* Updated all dependencies to latest release. (Dieter Oberkofler)

v0.4.0 - March 17, 2015
* 0.4.0 (Dieter Oberkofler)
* Finalized the error logging on console and the new `error.log` file. (Dieter Oberkofler)
* Startup aborted when no database connection can be established. (Dieter Oberkofler)
* Updated all dependencies to latest release. (Dieter Oberkofler)

v0.5.0 - March 24, 2015
* 0.5.0 (Dieter Oberkofler)
* Added support for associative array arguments. (Dieter Oberkofler)
* Better support of APEX applications. (Dieter Oberkofler)
* No PL/SQL code needs to be installed during server startup. (Dieter Oberkofler)
* Improved error messages from SQL statement fails. (Dieter Oberkofler)
* Updated all dependencies to latest release. (Dieter Oberkofler)

v0.6.0 - April 16, 2015
* 0.6.0 (Dieter Oberkofler)
* Complete redesign of the OCI interface. (Dieter Oberkofler)
* Added support for array binds to the OCI interface. (Dieter Oberkofler)
* Added support for multiple parameters with the same name. (Dieter Oberkofler)
* Added support for PL/SQL TABLE arguments in the invoked PL/SQL procedures. (Dieter Oberkofler)
* Improved error messages from SQL statement fails. (Dieter Oberkofler)
* Updated all dependencies to latest release. (Dieter Oberkofler)

==> node_plsql-0.6.1.tgz: package/HISTORY.md <==
v0.0.1 - May 24, 2014
* 0.0.1 (Dieter Oberkofler)
* initial check-in as a proof of concept. (Dieter Oberkofler)
* support for flexible parameter passing. (Dieter Oberkofler)
* support for all required cgi parameters including cookies. (Dieter Oberkofler)
* support for static files. (Dieter Oberkofler)
* support for non-blocking Oracle requests. (Dieter Oberkofler)
* support for Oracle connection pooling. (Dieter Oberkofler)

v0.0.2 - May 29, 2014
* 0.0.2 (Dieter Oberkofler)
* Added support for file uploads. (Dieter Oberkofler)
* Added support for parsing multipart-form data requests. (Dieter Oberkofler)
* Added support for form data requests. (Dieter Oberkofler)
* Added configuration option "requestLogging" allowing enable/disable the http request logging middleware. (Dieter Oberkofler)
* Switched from Makefile to Gruntfile. (Dieter Oberkofler)
* update "express" to 4.3.2 (Dieter Oberkofler)
* update "mocha" to 1.20.0 (Dieter Oberkofler)
* update "morgan" to 1.1.1 (Dieter Oberkofler)
* update "strip-json-comments" to 0.1.3 (Dieter Oberkofler)

v0.0.3 - May 30, 2014
* 0.0.3 (Dieter Oberkofler)
* Add support for darwin. (Dieter Oberkofler)

v0.0.4 - May 31, 2014
* 0.0.4 (Dieter Oberkofler)
* Add support for default pages. (Dieter Oberkofler)
* Added jscs linting. (Dieter Oberkofler)
* update "express" to 4.4.0 (Dieter Oberkofler)
* update "compression" to 1.0.3 (Dieter Oberkofler)
* update "serve-static" to 1.1.0 (Dieter Oberkofler)

v0.0.5 - May 31, 2014
* 0.0.5 (Dieter Oberkofler)
* Extracted the database interface and created a shim for testing purposes. (Dieter Oberkofler)
* Added integration test framework. (Dieter Oberkofler)
* Added proper error handling for 404 and 500 error messages. (Dieter Oberkofler)
* Added proper error handling for Oracle error messages. (Dieter Oberkofler)

v0.0.6 - skipped

v0.0.7 - June 12, 2014
* 0.0.7 (Dieter Oberkofler)
* Switched from blanket to istanbul for code coverage. (Dieter Oberkofler)
* Improved code coverage to 100%. (Dieter Oberkofler)
* update "body-parser" to 1.3.1 (Dieter Oberkofler)
* update "compression" to 1.0.7 (Dieter Oberkofler)
* update "connect-multiparty" to 1.0.5 (Dieter Oberkofler)
* update "debug" to 1.0.2 (Dieter Oberkofler)
* update "express" to 4.4.3 (Dieter Oberkofler)
* update "serve-static" to 1.2.3 (Dieter Oberkofler)

v0.0.8 - June 13, 2014
* 0.0.8 (Dieter Oberkofler)
* Just fixed a formatting error in README. (Dieter Oberkofler)

v0.0.9 - June 16, 2014
* 0.0.9 (Dieter Oberkofler)
* Added a basic status page. (Dieter Oberkofler)
* Fixed a logging error. (Dieter Oberkofler)

v0.0.10 - June 20, 2014
* 0.0.10 (Dieter Oberkofler)
* Added support for Node 0.11. (Dieter Oberkofler)
* Migrated v8 interface to nan. (Dieter Oberkofler)
* Fixed a small intermittent problem caused by using mkdirp in async mode. (Dieter Oberkofler)
* update "cookie-parser" to 1.3.1 (Dieter Oberkofler)
* update "body-parser" to 1.4.3 (Dieter Oberkofler)

v0.0.11 - June 21, 2014
* 0.0.11 (Dieter Oberkofler)
* Fixed usage mkdirp in async mode in test. (Dieter Oberkofler)
* Added unit tests for static files. (Dieter Oberkofler)
* update "compression" to 1.0.8 (Dieter Oberkofler)
* update "express" to 4.4.4 (Dieter Oberkofler)

v0.0.12 - August 16, 2014
* 0.0.12 (Dieter Oberkofler)
* Renamed the server module from lib/node_plsql.js to lib/server.js to make sure that only the client in bin is used locally. (Dieter Oberkofler)
* Adapted server to the latest express version. (Dieter Oberkofler)
* Added a better installation example in the README. (Dieter Oberkofler)
* Added separate documentation for local and global installation. (Dieter Oberkofler)
* Added missing configuration samples to the npm tarball. (Dieter Oberkofler)
* Separated the development information into a separate DEVELOPMENT.md file. (Dieter Oberkofler)
* update "body-parser" to 1.6.4 (Dieter Oberkofler)
* update "compression" to 1.0.11 (Dieter Oberkofler)
* update "connect-multiparty" to 1.2.1 (Dieter Oberkofler)
* update "cookie-parser" to 1.3.2 (Dieter Oberkofler)
* update "debug" to 1.0.4 (Dieter Oberkofler)
* update "express" to 4.8.4 (Dieter Oberkofler)
* update "js-yaml" to 3.1.0 (Dieter Oberkofler)
* update "morgan" to 1.2.2 (Dieter Oberkofler)
* update "nopt" to 3.0.1 (Dieter Oberkofler)
* update "serve-static" to 1.5.2 (Dieter Oberkofler)
* update "strip-json-comments" to 1.0.1 (Dieter Oberkofler)

v0.0.13 - October 27, 2014
* 0.0.13 (Dieter Oberkofler)
* update "body-parser" to 1.9.1 (Dieter Oberkofler)
* update "compression" to 1.2.0 (Dieter Oberkofler)
* update "connect-multiparty" to 1.2.5 (Dieter Oberkofler)
* update "cookie-parser" to 1.3.3 (Dieter Oberkofler)
* update "debug" to 2.1.0 (Dieter Oberkofler)
* update "express" to 4.10.0 (Dieter Oberkofler)
* update "js-yaml" to 3.2.3 (Dieter Oberkofler)
* update "morgan" to 1.4.1 (Dieter Oberkofler)
* update "serve-static" to 1.7.1 (Dieter Oberkofler)
* update "strip-json-comments" to 1.0.2 (Dieter Oberkofler)
* update "underscore" to 1.7.0 (Dieter Oberkofler)

v0.1.0 - November 11, 2014
* 0.1.0 (Dieter Oberkofler)
* Binaries (only node-v11-win32-x64) now hosted in S3 using node-pre-gyp (Dieter Oberkofler)
* Minor improvements in the usage of the cli. (Dieter Oberkofler)
* update "body-parser" to 1.9.2 (Dieter Oberkofler)
* update "js-yaml" to 3.2.3 (Dieter Oberkofler)
* update "nan" to 1.4.1 (Dieter Oberkofler)
* update "chai" to 1.10.0 (Dieter Oberkofler)
* update "morgan" to 1.5.0 (Dieter Oberkofler)
* update "express" to 4.10.2 (Dieter Oberkofler)

v0.1.1 - December 20, 2014
* 0.1.1 (Dieter Oberkofler)
* Binaries (only node-v11-win32-x64) now hosted in S3 using node-pre-gyp (Dieter Oberkofler)
* Migrated from grunt to gulp. (Dieter Oberkofler)
* update "body-parser" to 1.10.0 (Dieter Oberkofler)
* update "compression" to 1.2.2 (Dieter Oberkofler)
* update "express" to 4.10.6 (Dieter Oberkofler)
* update "js-yaml" to 3.2.4 (Dieter Oberkofler)
* update "ms" to 0.7.0 (Dieter Oberkofler)

v0.2.0 - March 4, 2015
* 0.2.0 (Dieter Oberkofler)
* Support for Node.js 0.2.0. (Dieter Oberkofler)
* Migrated from jshint and esjs to eslint. (Dieter Oberkofler)
* Updated all dependencies to latest release. (Dieter Oberkofler)
* Internal errors (500) now whow the internal error stack. (Dieter Oberkofler)

v0.3.0 - March 14, 2015
* 0.3.0 (Dieter Oberkofler)
* Impoved the CGI parameter available to the Oracle backend. (Dieter Oberkofler)
* Support for io.js. (Dieter Oberkofler)
* Updated all dependencies to latest release. (Dieter Oberkofler)

v0.4.0 - March 17, 2015
* 0.4.0 (Dieter Oberkofler)
* Finalized the error logging on console and the new `error.log` file. (Dieter Oberkofler)
* Startup aborted when no database connection can be established. (Dieter Oberkofler)
* Updated all dependencies to latest release. (Dieter Oberkofler)

v0.5.0 - March 24, 2015
* 0.5.0 (Dieter Oberkofler)
* Added support for associative array arguments. (Dieter Oberkofler)
* Better support of APEX applications. (Dieter Oberkofler)
* No PL/SQL code needs to be installed during server startup. (Dieter Oberkofler)
* Improved error messages from SQL statement fails. (Dieter Oberkofler)
* Updated all dependencies to latest release. (Dieter Oberkofler)

v0.6.0 - April 16, 2015
* 0.6.0 (Dieter Oberkofler)
* Complete redesign of the OCI interface. (Dieter Oberkofler)
* Added support for array binds to the OCI interface. (Dieter Oberkofler)
* Added support for multiple parameters with the same name. (Dieter Oberkofler)
* Added support for PL/SQL TABLE arguments in the invoked PL/SQL procedures. (Dieter Oberkofler)
* Improved error messages from SQL statement fails. (Dieter Oberkofler)
* Updated all dependencies to latest release. (Dieter Oberkofler)

v0.6.1 - April 17, 2015
* 0.6.1 (Dieter Oberkofler)
* Fixed some problems in the build for Linux and OSX. (Dieter Oberkofler)
